==> open5gs_2.2.8.tar.xz: BUILD/README.md <==
<h2 align="center">Supporting Open5GS</h2>

If you find Open5GS useful for work, please consider supporting this Open Source project by [Becoming a sponsor](https://github.com/sponsors/acetcom). To manage the funding transactions transparently, you can donate through [OpenCollective](https://opencollective.com/open5gs).

<h3 align="center">Special Sponsor</h3>
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle">
  <a href="https://nextepc.com/" target="_blank">
    <img width="260px" src="https://open5gs.org/assets/img/nextepc_logo.jpg">
  </a>
      </td>
      <td width="20px"></td>
      <td align="center" valign="middle">
  <a href="https://sdr.eee.strath.ac.uk/" target="_blank">
    <img width="260px" src="https://open5gs.org/assets/img/strath.png">
  </a>
      </td>
    </tr>
  </tbody>
</table>

<h3 align="center">Sponsors</h3>
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle">
        <a href="https://www.auctionsoftware.com/" target="_blank">
          <img width="222px" src="https://open5gs.org/assets/img/asLogonew.png">
        </a>
      </td>
      <td align="center" valign="middle">
        <a href="https://www.wearetriple.com/" target="_blank">
          <img width="222px" src="https://open5gs.org/assets/img/triple_logo.png">
        </a>
      </td>
      <td align="center" valign="middle">
        <a href="https://www.accessparks.com/" target="_blank">
          <img width="222px" src="https://open5gs.org/assets/img/AccessParks.png">
        </a>
      </td>
    </tr>
    <tr>
      <td align="center" valign="middle">
        <a href="https://skylarkwireless.com/" target="_blank">
          <img width="222px" src="https://open5gs.org/assets/img/SkylarkWireless-420x78-Web2-R.png">
        </a>
      </td>
    </tr>
  </tbody>
</table>

## Documentation

If you don't understand something about Open5GS, the [https://open5gs.org/open5gs/docs/](https://open5gs.org/open5gs/docs/) is a great place to look for answers.

## Community

- Problem with Open5GS can be filed as [issues](https://github.com/open5gs/open5gs/issues) in this repository.
- Other topics related to this project are happening on the [discussions](https://github.com/open5gs/open5gs/discussions).
- Voice and text chat are available in Open5GS's [Discord](https://discordapp.com/) workspace. Use [this link](https://discord.gg/GreNkuc) to get started.

## Contributing

If you're contributing through a pull request to Open5GS project on GitHub, please read the [Contributor License Agreement](https://open5gs.org/open5gs/cla/) in advance.

## License

- Open5GS Open Source files are made available under the terms of the GNU Affero General Public License ([GNU AGPL v3.0](https://www.gnu.org/licenses/agpl-3.0.html)).
- [Commercial licenses](https://open5gs.org/open5gs/support/) are also available from [NextEPC, Inc.](https://nextepc.com)

==> open5gs_2.3.0.tar.xz: BUILD/README.md <==
<h2 align="center">Supporting Open5GS</h2>

If you find Open5GS useful for work, please consider supporting this Open Source project by [Becoming a sponsor](https://github.com/sponsors/acetcom). To manage the funding transactions transparently, you can donate through [OpenCollective](https://opencollective.com/open5gs).

<h3 align="center">Special Sponsor</h3>
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle">
  <a href="https://nextepc.com/" target="_blank">
    <img width="260px" src="https://open5gs.org/assets/img/nextepc_logo.jpg">
  </a>
      </td>
      <td width="20px"></td>
      <td align="center" valign="middle">
  <a href="https://sdr.eee.strath.ac.uk/" target="_blank">
    <img width="260px" src="https://open5gs.org/assets/img/strath.png">
  </a>
      </td>
    </tr>
  </tbody>
</table>

<h3 align="center">Sponsors</h3>
<table>
  <tbody>
    <tr>
      <td align="center" valign="middle" height="100px" width="222px">
        <a href="https://www.auctionsoftware.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/asLogonew.png">
        </a>
      </td>
      <td align="center" valign="middle" height="100px" width="222px">
        <a href="https://www.wearetriple.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/triple_logo.png">
        </a>
      </td>
      <td align="center" valign="middle" height="100px" width="222px">
        <a href="https://www.accessparks.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/AccessParks.png">
        </a>
      </td>
    </tr>
    <tr>
      <td align="center" valign="middle" height="100px" width="222px">
        <a href="https://skylarkwireless.com/" target="_blank">
          <img src="https://open5gs.org/assets/img/SkylarkWireless-420x78-Web2-R.png">
        </a>
      </td>
      <td align="center" valign="middle" height="100px" width="222px">
        <a href="https://sysmocom.de/" target="_blank">
          <img src="https://open5gs.org/assets/img/sysmocom-logo.png">
        </a>
      </td>
    </tr>
  </tbody>
</table>

## Documentation

If you don't understand something about Open5GS, the [https://open5gs.org/open5gs/docs/](https://open5gs.org/open5gs/docs/) is a great place to look for answers.

## Community

- Problem with Open5GS can be filed as [issues](https://github.com/open5gs/open5gs/issues) in this repository.
- Other topics related to this project are happening on the [discussions](https://github.com/open5gs/open5gs/discussions).
- Voice and text chat are available in Open5GS's [Discord](https://discordapp.com/) workspace. Use [this link](https://discord.gg/GreNkuc) to get started.

## Contributing

If you're contributing through a pull request to Open5GS project on GitHub, please read the [Contributor License Agreement](https://open5gs.org/open5gs/cla/) in advance.

## License

- Open5GS Open Source files are made available under the terms of the GNU Affero General Public License ([GNU AGPL v3.0](https://www.gnu.org/licenses/agpl-3.0.html)).
- [Commercial licenses](https://open5gs.org/open5gs/support/) are also available from [NextEPC, Inc.](https://nextepc.com)
